==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/MATLIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour MATLIST_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="MATLIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MTLCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MTLREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MATLIST_Type", propOrder = {
    "mtlcode",
    "mtlrevision",
    "description"
})
public class MATLIST_Type {

    @XmlElement(name = "MTLCODE", required = true)
    protected String mtlcode;
    @XmlElement(name = "MTLREVISION")
    protected long mtlrevision;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété mtlcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMTLCODE() {
        return mtlcode;
    }

    /**
     * Définit la valeur de la propriété mtlcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMTLCODE(String value) {
        this.mtlcode = value;
    }

    /**
     * Obtient la valeur de la propriété mtlrevision.
     * 
     */
    public long getMTLREVISION() {
        return mtlrevision;
    }

    /**
     * Définit la valeur de la propriété mtlrevision.
     * 
     */
    public void setMTLREVISION(long value) {
        this.mtlrevision = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/MATLIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MATLIST_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MATLIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MTLCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MTLREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MATLIST_Type", propOrder = {
    "mtlcode",
    "mtlrevision",
    "description"
})
public class MATLIST_Type {

    @XmlElement(name = "MTLCODE", required = true)
    protected String mtlcode;
    @XmlElement(name = "MTLREVISION")
    protected long mtlrevision;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the mtlcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMTLCODE() {
        return mtlcode;
    }

    /**
     * Sets the value of the mtlcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMTLCODE(String value) {
        this.mtlcode = value;
    }

    /**
     * Gets the value of the mtlrevision property.
     * 
     */
    public long getMTLREVISION() {
        return mtlrevision;
    }

    /**
     * Sets the value of the mtlrevision property.
     * 
     */
    public void setMTLREVISION(long value) {
        this.mtlrevision = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
